==> zio-aws-iotsitewise_2.12-5.17.145.1-sources.jar: zio/aws/iotsitewise/model/AssociateTimeSeriesToAssetPropertyRequest.scala <==
package zio.aws.iotsitewise.model
import zio.ZIO
import zio.aws.iotsitewise.model.primitives.{ClientToken, ID, PropertyAlias}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AssociateTimeSeriesToAssetPropertyRequest(
    alias: PropertyAlias,
    assetId: ID,
    propertyId: ID,
    clientToken: Option[ClientToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest = {
    import AssociateTimeSeriesToAssetPropertyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
      .builder()
      .alias(PropertyAlias.unwrap(alias): java.lang.String)
      .assetId(ID.unwrap(assetId): java.lang.String)
      .propertyId(ID.unwrap(propertyId): java.lang.String)
      .optionallyWith(
        clientToken.map(value => ClientToken.unwrap(value): java.lang.String)
      )(_.clientToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest.ReadOnly =
    zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
      .wrap(buildAwsValue())
}
object AssociateTimeSeriesToAssetPropertyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest =
      zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest(
        alias,
        assetId,
        propertyId,
        clientToken.map(value => value)
      )
    def alias: PropertyAlias
    def assetId: ID
    def propertyId: ID
    def clientToken: Option[ClientToken]
    def getAlias: ZIO[Any, Nothing, PropertyAlias] = ZIO.succeed(alias)
    def getAssetId: ZIO[Any, Nothing, ID] = ZIO.succeed(assetId)
    def getPropertyId: ZIO[Any, Nothing, ID] = ZIO.succeed(propertyId)
    def getClientToken: ZIO[Any, AwsError, ClientToken] =
      AwsError.unwrapOptionField("clientToken", clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
  ) extends zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest.ReadOnly {
    override val alias: PropertyAlias =
      zio.aws.iotsitewise.model.primitives.PropertyAlias(impl.alias())
    override val assetId: ID =
      zio.aws.iotsitewise.model.primitives.ID(impl.assetId())
    override val propertyId: ID =
      zio.aws.iotsitewise.model.primitives.ID(impl.propertyId())
    override val clientToken: Option[ClientToken] = scala
      .Option(impl.clientToken())
      .map(value => zio.aws.iotsitewise.model.primitives.ClientToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
  ): zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotsitewise_2.12-5.17.195.3-sources.jar: zio/aws/iotsitewise/model/AssociateTimeSeriesToAssetPropertyRequest.scala <==
package zio.aws.iotsitewise.model
import zio.ZIO
import zio.aws.iotsitewise.model.primitives.{ClientToken, ID, PropertyAlias}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AssociateTimeSeriesToAssetPropertyRequest(
    alias: PropertyAlias,
    assetId: ID,
    propertyId: ID,
    clientToken: Optional[ClientToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest = {
    import AssociateTimeSeriesToAssetPropertyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
      .builder()
      .alias(PropertyAlias.unwrap(alias): java.lang.String)
      .assetId(ID.unwrap(assetId): java.lang.String)
      .propertyId(ID.unwrap(propertyId): java.lang.String)
      .optionallyWith(
        clientToken.map(value => ClientToken.unwrap(value): java.lang.String)
      )(_.clientToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest.ReadOnly =
    zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
      .wrap(buildAwsValue())
}
object AssociateTimeSeriesToAssetPropertyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest =
      zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest(
        alias,
        assetId,
        propertyId,
        clientToken.map(value => value)
      )
    def alias: PropertyAlias
    def assetId: ID
    def propertyId: ID
    def clientToken: Optional[ClientToken]
    def getAlias: ZIO[Any, Nothing, PropertyAlias] = ZIO.succeed(alias)
    def getAssetId: ZIO[Any, Nothing, ID] = ZIO.succeed(assetId)
    def getPropertyId: ZIO[Any, Nothing, ID] = ZIO.succeed(propertyId)
    def getClientToken: ZIO[Any, AwsError, ClientToken] =
      AwsError.unwrapOptionField("clientToken", clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
  ) extends zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest.ReadOnly {
    override val alias: PropertyAlias =
      zio.aws.iotsitewise.model.primitives.PropertyAlias(impl.alias())
    override val assetId: ID =
      zio.aws.iotsitewise.model.primitives.ID(impl.assetId())
    override val propertyId: ID =
      zio.aws.iotsitewise.model.primitives.ID(impl.propertyId())
    override val clientToken: Optional[ClientToken] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => zio.aws.iotsitewise.model.primitives.ClientToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest
  ): zio.aws.iotsitewise.model.AssociateTimeSeriesToAssetPropertyRequest.ReadOnly =
    new Wrapper(impl)
}
